<?php
/**
 * Class description
 *
 * @package   package_name
 * @author    Cherry Team
 * @license   GPL-2.0+
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'Jet_Theme_Core_Config' ) ) {

	/**
	 * Define Jet_Theme_Core_Config class
	 */
	class Jet_Theme_Core_Config {

		/**
		 * A reference to an instance of this class.
		 *
		 * @since 1.0.0
		 * @var   object
		 */
		private static $instance = null;

		/**
		 * Config holder
		 *
		 * @var array
		 */
		private $config = array();


		/**
		 * Constructor for the class
		 */
		public function __construct() {

			// register default config
			$this->config =  array(
				'dashboard_page_name' => esc_html__( 'Theme Core', 'jet-theme-core' ),
				'documentation' => 'http://documentation.zemez.io/wordpress/index.php?project=kava-child',
				'editor' => array(
					'template_before' => '',
					'template_after'  => '',
				),
				'library_button' => esc_html__( 'Magic Button', 'jet-theme-core' ),
				'menu_icon' => 'dashicons-welcome-widgets-menus',
				'library' => array(
					'version' => '1.0.0',
					'tabs'    => array(
						'header'  => '',
						'footer'  => '',
						'section' => '',
						'page'    => '',
					),
					'keywords' => array(),
				),
				'guide' => array(
					'enabled' => true,
					'title'   => __( 'Learn More About Your Theme', 'jet-theme-core' ),
					'content' => __( 'Here you can get all the necessary information, detailed instructions and latest news.', 'jet-theme-core' ),
					'links'   => array(
						'documentation' => array(
							'label'  => __( 'Check documentation', 'jet-theme-core' ),
							'type'   => 'primary',
							'target' => '_blank',
							'icon'   => 'dashicons-welcome-learn-more',
							'desc'   => __( 'Get more info from documentation', 'jet-theme-core' ),
							'url'    => 'http://documentation.zemez.io/wordpress/index.php?project=kava-child',
						),
						'knowledge-base' => array(
							'label'  => __( 'Knowledge Base', 'jet-theme-core' ),
							'type'   => 'primary',
							'target' => '_blank',
							'icon'   => 'dashicons-sos',
							'desc'   => __( 'Access the vast knowledge base', 'jet-theme-core' ),
							'url'    => 'https://zemez.io/wordpress/support/knowledge-base/',
						),
					),
				),
				'api' => array(
					'enabled'   => false,
					'base'      => 'https://account.crocoblock.com/',
					'path'      => 'wp-json/croco/v1',
					'id'        => 9,
					'endpoints' => array(
						'templates'  => '/templates/',
						'keywords'   => '/keywords/',
						'categories' => '/categories/',
						'info'       => '/info/',
						'template'   => '/template/',
						'plugins'    => '/plugins/',
						'plugin'     => '/plugin/',
					),
				),
				'skins' => array(
					'enabeld' => false,
					'synch'   => false,
				),
			);

			/**
			 * Register custom config on this hook
			 */
			do_action( 'jet-theme-core/register-config', $this );
		}

		/**
		 * Register custom config from theme or plugin
		 *
		 * @param  array $config Config to register
		 * @return void
		 */
		public function register_config( $config ) {

			foreach ( $config as $key => $data ) {

				if ( ! empty( $this->config[ $key ] ) ) {
					if ( is_array( $this->config[ $key ] ) ) {
						$this->config[ $key ] = array_merge( $this->config[ $key ], $data );
					} else {
						$this->config[ $key ] = $data;
					}
				} else {
					$this->config[ $key ] = $data;
				}

			}

		}

		/**
		 * Returns config value by key
		 *
		 * @param  string $key Key to get.
		 * @return mixed
		 */
		public function get( $key = '' ) {
			return isset( $this->config[ $key ] ) ? $this->config[ $key ] : false;
		}

		/**
		 * Returns the instance.
		 *
		 * @since  1.0.0
		 * @return object
		 */
		public static function get_instance() {

			// If the single instance hasn't been set, set it now.
			if ( null == self::$instance ) {
				self::$instance = new self;
			}
			return self::$instance;
		}
	}

}
